@@ -3,7 +3,7 @@
 
 use std::env;
 
-use chrono::{DateTime, FixedOffset};
+use jiff::Zoned;
 use parse_datetime::{parse_datetime, parse_datetime_at_date};
 
 pub fn check_absolute(input: &str, expected: &str) {
@@ -15,19 +15,23 @@ pub fn check_absolute(input: &str, expected: &str) {
     };
 
     assert_eq!(
-        &parsed.to_rfc3339().replace("T", " "),
+        parsed.strftime("%Y-%m-%d %H:%M:%S%:z").to_string(),
         expected,
         "Input value: {input}"
     );
 }
 
-pub fn check_relative(now: DateTime<FixedOffset>, input: &str, expected: &str) {
+pub fn check_relative(now: Zoned, input: &str, expected: &str) {
     env::set_var("TZ", "UTC0");
 
-    let parsed = match parse_datetime_at_date(now.into(), input) {
+    let parsed = match parse_datetime_at_date(now, input) {
         Ok(v) => v,
         Err(e) => panic!("Failed to parse date from value '{input}': {e}"),
     };
-    let expected_parsed = DateTime::parse_from_rfc3339(expected).unwrap();
-    assert_eq!(parsed, expected_parsed, "Input value: {input}");
+
+    assert_eq!(
+        parsed.strftime("%Y-%m-%d %H:%M:%S%:z").to_string(),
+        expected,
+        "Input value: {input}"
+    );
 }
